==> duckdb_0.3.2.tar.gz: duckdb/src/duckdb/amalgamation-18.cpp <==
#include "src/storage/compression/rle.cpp"

#include "src/storage/compression/string_uncompressed.cpp"

#include "src/storage/compression/uncompressed.cpp"

#include "src/storage/compression/validity_uncompressed.cpp"

#include "src/storage/data_table.cpp"

#include "src/storage/index.cpp"

#include "src/storage/local_storage.cpp"

#include "src/storage/meta_block_reader.cpp"

#include "src/storage/meta_block_writer.cpp"

#include "src/storage/single_file_block_manager.cpp"

#include "src/storage/statistics/base_statistics.cpp"

#include "src/storage/statistics/list_statistics.cpp"

#include "src/storage/statistics/numeric_statistics.cpp"

#include "src/storage/statistics/segment_statistics.cpp"

#include "src/storage/statistics/string_statistics.cpp"

#include "src/storage/statistics/struct_statistics.cpp"

#include "src/storage/statistics/validity_statistics.cpp"

#include "src/storage/storage_info.cpp"

#include "src/storage/storage_lock.cpp"

#include "src/storage/storage_manager.cpp"

#include "src/storage/table/chunk_info.cpp"

#include "src/storage/table/column_checkpoint_state.cpp"

#include "src/storage/table/column_data.cpp"

#include "src/storage/table/column_data_checkpointer.cpp"

#include "src/storage/table/column_segment.cpp"

#include "src/storage/table/list_column_data.cpp"

#include "src/storage/table/persistent_table_data.cpp"

#include "src/storage/table/row_group.cpp"

#include "src/storage/table/segment_tree.cpp"

#include "src/storage/table/standard_column_data.cpp"

#include "src/storage/table/struct_column_data.cpp"

#include "src/storage/table/update_segment.cpp"

#include "src/storage/table/validity_column_data.cpp"

#include "src/storage/wal_replay.cpp"

#include "src/storage/write_ahead_log.cpp"

#include "src/transaction/cleanup_state.cpp"

#include "src/transaction/commit_state.cpp"

#include "src/transaction/rollback_state.cpp"

#include "src/transaction/transaction.cpp"

#include "src/transaction/transaction_context.cpp"

#include "src/transaction/transaction_manager.cpp"

#include "src/transaction/undo_buffer.cpp"

==> duckdb_0.3.4-1.tar.gz: duckdb/src/duckdb/amalgamation-18.cpp <==
#include "src/storage/compression/dictionary_compression.cpp"

#include "src/storage/compression/fixed_size_uncompressed.cpp"

#include "src/storage/compression/numeric_constant.cpp"

#include "src/storage/compression/rle.cpp"

#include "src/storage/compression/string_uncompressed.cpp"

#include "src/storage/compression/uncompressed.cpp"

#include "src/storage/compression/validity_uncompressed.cpp"

#include "src/storage/data_table.cpp"

#include "src/storage/index.cpp"

#include "src/storage/local_storage.cpp"

#include "src/storage/meta_block_reader.cpp"

#include "src/storage/meta_block_writer.cpp"

#include "src/storage/single_file_block_manager.cpp"

#include "src/storage/statistics/base_statistics.cpp"

#include "src/storage/statistics/list_statistics.cpp"

#include "src/storage/statistics/numeric_statistics.cpp"

#include "src/storage/statistics/segment_statistics.cpp"

#include "src/storage/statistics/string_statistics.cpp"

#include "src/storage/statistics/struct_statistics.cpp"

#include "src/storage/statistics/validity_statistics.cpp"

#include "src/storage/storage_info.cpp"

#include "src/storage/storage_lock.cpp"

#include "src/storage/storage_manager.cpp"

#include "src/storage/table/chunk_info.cpp"

#include "src/storage/table/column_checkpoint_state.cpp"

#include "src/storage/table/column_data.cpp"

#include "src/storage/table/column_data_checkpointer.cpp"

#include "src/storage/table/column_segment.cpp"

#include "src/storage/table/list_column_data.cpp"

#include "src/storage/table/persistent_table_data.cpp"

#include "src/storage/table/row_group.cpp"

#include "src/storage/table/segment_tree.cpp"

#include "src/storage/table/standard_column_data.cpp"

#include "src/storage/table/struct_column_data.cpp"

#include "src/storage/table/update_segment.cpp"

#include "src/storage/table/validity_column_data.cpp"

#include "src/storage/wal_replay.cpp"

#include "src/storage/write_ahead_log.cpp"

#include "src/transaction/cleanup_state.cpp"

#include "src/transaction/commit_state.cpp"

#include "src/transaction/rollback_state.cpp"

#include "src/transaction/transaction.cpp"

#include "src/transaction/transaction_context.cpp"

#include "src/transaction/transaction_manager.cpp"

#include "src/transaction/undo_buffer.cpp"
